@@ -2,10 +2,11 @@ convert2bcsft <- function(cross, BC.gen = 0, F.gen = 0, estimate.map = TRUE,
                           error.prob=0.0001, map.function=c("haldane","kosambi","c-f","morgan"),
                           verbose=FALSE)
 {
-    cross.class <- class(cross)[1]
+    cross.class <- crosstype(cross)
+    if(cross.class=="bcsft") cross.class <- "f2"
 
     if((cross.class %in% c("bc","f2"))) {
-        class(cross)[1] <- "bcsft"
+        class(cross) <- c("bcsft", "cross")
         ## If BC.gen = 0 and F.gen = 0, then set to BC1F0 (bc) or BC0F2 (f2).
         if(cross.class == "bc" & F.gen > 0) {
             stop("input cross has only 2 genotypes--cannot have F.gen > 0")
@@ -51,8 +52,24 @@ read.cross.bcsft <- function(..., BC.gen = 0, F.gen = 0, cross = NULL, force.bcs
         estimate.map <- FALSE
 
     force.bcsft <- force.bcsft | (BC.gen > 0 | F.gen > 0)
-    if((class(cross)[1] %in% c("bc","f2")) & force.bcsft)
-        cross <- convert2bcsft(cross, BC.gen, F.gen, estimate.map = estimate.map, ...)
+    if((crosstype(cross) %in% c("bc","f2","bcsft")) && force.bcsft) {
+
+        # deal with ... args
+        dots <- list(...)
+
+        if("verbose" %in% names(dots)) verbose <- dots$verbose
+        else verbose <- TRUE
+
+        if("error.prob" %in% names(dots)) error.prob <- dots$error.prob
+        else error.prob <- 0.0001
+
+        if("map.function" %in% names(dots)) map.function <- dots$map.function
+        else map.function <- "haldane"
+
+        cross <- convert2bcsft(cross, BC.gen, F.gen, estimate.map = estimate.map,
+                               error.prob=error.prob, map.function=map.function,
+                               verbose=verbose)
+    }
 
     cross
 }
@@ -83,9 +100,7 @@ sim.cross.bcsft <- function(map,model,n.ind,error.prob,missing.prob,
     n.eff <- 3 + (cross.scheme[2] > 0)
 
     ## chromosome types
-    chr.type <- sapply(map,function(a)
-                       if(is.null(class(a))) return("A")
-                       else return(class(a)))
+    chr.type <- sapply(map,chrtype)
 
     n.chr <- length(map)
     if(is.null(model)) n.qtl <- 0
